<?php

namespace Teknisa\FIN\Modules\ContaPagar\Factory;

use Doctrine\ORM\EntityManager;
use Teknisa\Libs\Util\DateUtil;
use Teknisa\Model\Financeiro\Entities\Adiantapagar;
use Teknisa\Model\Geral\Entities\Empresa;
use Teknisa\Model\Geral\Entities\Fornecedor;
use Teknisa\Model\Geral\Entities\Centcustfil;
use Teknisa\Model\Fiscal\Entities\Notafiscal;
use Teknisa\Model\Suprimentos\Entities\Antecipaforne;
use Teknisa\Model\Financeiro\Entities\Ccorforn;
use Teknisa\Model\Financeiro\Entities\Rattpctp;
use Teknisa\Model\Financeiro\Entities\Ajbolpag;
use Teknisa\Model\Financeiro\Entities\Ajctpagar;
use Teknisa\Model\Financeiro\Entities\Boletpagar;
use Teknisa\Model\Financeiro\Entities\Ratctpagar;
use Teknisa\Model\Financeiro\Entities\Contapagar;
use Teknisa\Model\Financeiro\Entities\Tipoajpagar;
use Teknisa\Model\Financeiro\Entities\Devolucaopag;
use Teknisa\Model\Financeiro\Entities\GeralPag;
use Teknisa\Model\Financeiro\Entities\Emprbanc;
use Teknisa\Model\Fiscal\Entities\Impbaixapag;
use Teknisa\Model\Contabilidade\Entities\Lanccont;

/**
 * Class TitulosAPagarFactory
 * @package Teknisa\FIN\Modules\ContaPagar\Factory
 */
class TitulosAPagarFactory {

    protected $entityManager;

    /**
     * @param EntityManager $entityManager
     */
    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    /**
     * Busca Empresa
     * @param $nrorg
     * @param $cdempresa
     * @return Empresa
     */
    public function buscaEmpresa($nrorg, $cdempresa){
        /** @var $params */
        $params = array();
        $params['nrorg']     = $nrorg;
        $params['cdempresa'] = $cdempresa;

        /** @var Empresa $empresa */
        $empresa = $this->entityManager->getRepository(Empresa::class)->findOneBy($params);

        return $empresa;
    }

    /**
     * Busca Empresa
     * @param $nrorg
     * @param $cdempresa
     * @param $cdbanco
     * @return Empresa
     */
    public function buscaEmprbanc($nrorg, $cdempresa, $cdbanco){
        /** @var $params */
        $params = array();
        $params['nrorg']     = $nrorg;
        $params['cdempresa'] = $cdempresa;
        $params['cdbanco']   = $cdbanco;

        /** @var Empresa $empresa */
        $empresa = $this->entityManager->getRepository(Emprbanc::class)->findOneBy($params);

        return $empresa;
    }
    
    /**
     * Busca Ajuste Boleto Pagar
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlanbolpag
     * @param string $idorigajbpag
     * @return Ajbolpag
     */
    public function buscaAjusteBoletoPagar($nrorg, $cdfilial, $nrlanbolpag, $idorigajbpag = '4')
    {
        /** @var $params */
        $params = array();
        $params['nrorg']        = $nrorg;
        $params['cdfilial']     = $cdfilial;
        $params['nrlanbolpag']  = $nrlanbolpag;
        $params['idorigajbpag'] = $idorigajbpag;

        /** @var Ajbolpag $ajbolpag */
        $ajbolpag = $this->entityManager->getRepository(Ajbolpag::class)->findBy($params);

        return $ajbolpag;
    }
    
    
    public function buscaTodosAjustesBoletos($cdFilialLanBolPag) {
        $sql = "SELECT 'X' IDOPERACAO,
          AJ.CDAJUCTPAG,
          TA.DSAJUCTPAG,
          TA.IDAJUCTPAG,
          AJ.VRAJBOLPAG,
          AJ.NRORG,
          AJ.CDFILIAL,
          AJ.NRLANBOLPAG,
          AJ.IDORIGAJBPAG
        FROM AJBOLPAG AJ,
          TIPOAJPAGAR TA
        WHERE AJ.NRORG    = TA.NRORG
        AND AJ.CDAJUCTPAG = TA.CDAJUCTPAG
        AND AJ.CDFILIAL||AJ.NRLANBOLPAG IN $cdFilialLanBolPag";

        $std = $this->connection->prepare($sql);
        $std->execute();
        return $std->fetchAll();
    }
    
    /**
     * Busca Ajuste Titulo
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlanbolpag
     * @param $cdajuctpag
     * @return Ajbolpag
     */
    public function buscaAjusteTitulo($nrorg, $cdfilial, $nrlanbolpag, $cdajuctpag)
    {
        /** @var $params */
        $params = array();
        $params['nrorg']       = $nrorg;
        $params['cdfilial']    = $cdfilial;
        $params['nrlanbolpag'] = $nrlanbolpag;
        $params['cdajuctpag']  = $cdajuctpag;

        /** @var Ajbolpag $ajbolpag */
        $ajbolpag = $this->entityManager->getRepository(Ajbolpag::class)->findOneBy($params);

        return $ajbolpag;
    }

    /**
     * Busca Fornecedor
     * @param $nrorg
     * @param $cdforneced
     * @return Fornecedor
     */
    public function buscaFornecedor($nrorg, $cdforneced){
        /** @var $params */
        $params = array();
        $params['nrorg']      = $nrorg;
        $params['cdforneced'] = $cdforneced;

        /** @var Fornecedor $fornecedor */
        $fornecedor = $this->entityManager->getRepository(Fornecedor::class)->findOneBy($params);

        return $fornecedor;
    }

    /**
     * Busca Conta Corrente Fornecedor
     * @param $nrorg
     * @param $cdforneced
     * @return Fornecedor
     */
    public function buscaCcorforn($nrorg, $cdforneced, $idccorfornpref){
        /** @var $params */
        $params = array();
        $params['nrorg']          = $nrorg;
        $params['cdforneced']     = $cdforneced;
        $params['idccorfornpref'] = $idccorfornpref;

        /** @var Ccorforn $ccorforn */
        $ccorforn = $this->entityManager->getRepository(Ccorforn::class)->findOneBy($params);

        return $ccorforn;
    }

    /**
     * Busca Rateio Conta Pagar
     * @param $nrorg
     * @param $nrlanctonf
     * @param $cdfilial
     * @param $nrseqvenpag
     * @param $nrparcelapag
     * @param $cdfilirece
     * @return Ratctpagar
     */
    public function buscaRatCtPagar($nrorg, $nrlanctonf, $cdfilial, $nrseqvenpag, $nrparcelapag, $cdfilirece){
        /** @var $params */
        $params = array();
        $params['nrorg']        = $nrorg;
        $params['cdfilial']     = $cdfilial;
        $params['cdfiratctpag'] = $cdfilirece;
        $params['nrlanctonf']   = $nrlanctonf;
        $params['nrparcelapag'] = $nrparcelapag;
        $params['nrseqvenpag']  = $nrseqvenpag;

        /** @var Ratctpagar $ratctpagar */
        $ratctpagar = $this->entityManager->getRepository(Ratctpagar::class)->findBy($params);

        return $ratctpagar;
    }

    /**
     * Busca Rateio Tipo de Conta Pagar
     * @param $nrorg
     * @param $cdtpctpagar
     * @return Rattpctp
     */
    public function buscaRatTpCtP($nrorg, $cdtpctpagar){
        /** @var $params */
        $params = array();
        $params['nrorg']       = $nrorg;
        $params['cdtpctpagar'] = $cdtpctpagar;

        /** @var Rattpctp $rattpctp */
        $rattpctp = $this->entityManager->getRepository(Rattpctp::class)->findBy($params);

        return $rattpctp;
    }

    /**
     * Busca Centro de Custo Filial
     * @param $nrorg
     * @param $cdfilial
     * @return Centcustfil
     */
    public function buscaCentCustFil($nrorg, $cdfilial){
        /** @var $params */
        $params = array();
        $params['nrorg']    = $nrorg;
        $params['cdfilial'] = $cdfilial;

        /** @var Centcustfil $centcustfil */
        $centcustfil = $this->entityManager->getRepository(Centcustfil::class)->findOneBy($params);

        return $centcustfil;
    }
    
    /**
     * Busca Centro de Custo Filial
     * @param $cdfilial
     * @param $cdempresa
     * @return array
     */
    public function buscaCentCustFili(
        $cdfilial, $cdempresa
    ){

        /** @var $params */
        $params = array();
        $params['P_CDFILIAL' ] = $cdfilial;
        $params['P_CDEMPRESA'] = $cdempresa;

        $sql = "SELECT F.CDFILIAL, NVL(F.CDCENTCUST, E.CDCENTCUST) AS CDCENTCUST
                  FROM FILIAL F, EMPRESA E
                 WHERE F.CDFILIAL   = :P_CDFILIAL  AND
                       E.CDEMPRESA  = :P_CDEMPRESA AND
                       (F.CDEMPRESA = E.CDEMPRESA)
                 UNION
                SELECT F.CDFILIAL, NVL(F.CDCENTCUST, E.CDCENTCUST) AS CDCENTCUST
                  FROM FILIAL F, EMPRESA E, EMPRCNTRFIL EC
                 WHERE EC.CDFILIAL  = :P_CDFILIAL  AND
                       EC.CDEMPRESA = :P_CDEMPRESA AND
                       E.CDEMPRESA  = EC.CDEMPRESA AND
                       (F.CDFILIAL  = EC.CDFILIAL)";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    /**
     * Busca Boleto a Pagar
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlanbolpag
     * @return BoletPagar
     */
    public function buscaBoletPagar($nrorg, $cdfilial, $nrlanbolpag){
        /** @var $params */
        $params = array();
        $params['nrorg']       = $nrorg;
        $params['cdfilial']    = $cdfilial;
        $params['nrlanbolpag'] = $nrlanbolpag;

        /** @var Boletpagar $boletpagar */
        $boletpagar = $this->entityManager->getRepository(Boletpagar::class)->findOneBy($params);

        return $boletpagar;
    }
    
    /**
     * Busca Boleto a Pagar Parcelado
     * @param $nrorg
     * @param $cdfilial
     * @param $nrorigbolpag
     * @param $nrparcbolpag
     * @return BoletPagar
     */
    public function buscaBoletoParcelado($nrorg, $cdfilial, $nrorigbolpag, $nrparcbolpag){
        /** @var $params */
        $params = array();
        $params['nrorg']       = $nrorg;
        $params['cdfilial']    = $cdfilial;
        $params['nrorigbolpag'] = $nrorigbolpag;
        $params['nrparcbolpag'] = $nrparcbolpag;

        /** @var Boletpagar $boletpagar */
        $boletpagar = $this->entityManager->getRepository(Boletpagar::class)->findOneBy($params);

        return $boletpagar;
    }

    /**
     * Busca Antecipação Fornecedor
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlancantecipa
     * @return Antecipaforne
     */
    public function buscaAntecipaforne($nrorg, $cdfilial, $nrlancantecipa){
        /** @var $params */
        $params = array();
        $params['nrorg']          = $nrorg;
        $params['cdfilial']       = $cdfilial;
        $params['nrlancantecipa'] = $nrlancantecipa;

        /** @var Antecipaforne $antecipaforne */
        $antecipaforne = $this->entityManager->getRepository(Antecipaforne::class)->findOneBy($params);

        return $antecipaforne;
    }

    /**
     * Busca Titulos Antecipados
     * @param $nrorg
     * @param $cdfililanc
     * @param $nrlancantecipa
     * @return Boletpagar
     */
    public function buscaBoletosAntecipados($nrorg, $cdfililanc, $nrlancantecipa){
        /** @var $params */
        $params = array();
        $params['nrorg']          = $nrorg;
        $params['cdfililanc']     = $cdfililanc;
        $params['nrlancantecipa'] = $nrlancantecipa;

        /** @var Boletpagar $boletpagar */
        $boletpagar = $this->entityManager->getRepository(Boletpagar::class)->findBy($params);

        return $boletpagar;
    }

    /**
     * Busca Conta a Pagar
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlanbolpag
     * @return Contapagar
     */
    public function buscaContapagar($nrorg, $cdfilial, $nrlanbolpag){
        /** @var $params */
        $params = array();
        $params['nrorg']       = $nrorg;
        $params['cdfilibpag']  = $cdfilial;
        $params['nrlanbolpag'] = $nrlanbolpag;

        /** @var Contapagar $contapagar */
        $contapagar = $this->entityManager->getRepository(Contapagar::class)->findOneBy($params);

        return $contapagar;
    }

    /**
     * Busca Conta a Pagar
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlanctonf
     * @param $nrparcelapag
     * @param $nrseqvenpag
     * @return Contapagar
     */
    public function buscaContaPagarParcela($nrorg, $cdfilial, $nrlanctonf, $nrparcelapag, $nrseqvenpag){
        /** @var $params */
        $params = array();
        $params['nrorg']        = $nrorg;
        $params['cdfilial']     = $cdfilial;
        $params['nrlanctonf']   = $nrlanctonf;
        $params['nrparcelapag'] = $nrparcelapag;
        $params['nrseqvenpag']  = $nrseqvenpag;

        /** @var Contapagar $contapagar */
        $contapagar = $this->entityManager->getRepository(Contapagar::class)->findOneBy($params);

        return $contapagar;
    }

    /**
     * Busca Contas a Pagar
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlanctonf
     * @return Contapagar
     */
    public function buscaContaspagar($nrorg, $cdfilial, $nrlanctonf){
        /** @var $params */
        $params = array();
        $params['nrorg']      = $nrorg;
        $params['cdfilial']   = $cdfilial;
        $params['nrlanctonf'] = $nrlanctonf;

        /** @var Contapagar $contapagar */
        $contapagar = $this->entityManager->getRepository(Contapagar::class)->findBy($params);

        return $contapagar;
    }

    /**
     * Busca Contas a Pagar
     * @param $nrorg
     * @param $cdfilibpag
     * @param $nrlanbolpag
     * @return Contapagar
     */
    public function buscaContaspagarAssoc($nrorg, $cdfilibpag, $nrlanbolpag){
        /** @var $params */
        $params = array();
        $params['nrorg']       = $nrorg;
        $params['cdfilibpag']  = $cdfilibpag;
        $params['nrlanbolpag'] = $nrlanbolpag;

        /** @var Contapagar $contapagar */
        $contapagar = $this->entityManager->getRepository(Contapagar::class)->findBy($params);

        return $contapagar;
    }

    /**
     * Busca Nota Fiscal
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlanctonf
     * @return Notafiscal
     */
    public function buscaNotafiscal($nrorg, $cdfilial, $nrlanctonf){
        /** @var $params */
        $params = array();
        $params['nrorg']      = $nrorg;
        $params['cdfilial']   = $cdfilial;
        $params['nrlanctonf'] = $nrlanctonf;

        /** @var Notafiscal $notafiscal */
        $notafiscal = $this->entityManager->getRepository(Notafiscal::class)->findOneBy($params);

        return $notafiscal;
    }

    /**
     * Busca Tipo de Ajuste Pagar
     * @param $nrorg
     * @param $cdajuctpag
     * @return Tipoajpagar
     */
    public function buscaTipoajpagar($nrorg, $cdajuctpag){
        /** @var $params */
        $params = array();
        $params['nrorg']      = $nrorg;
        $params['cdajuctpag'] = $cdajuctpag;

        /** @var Tipoajpagar $tipoajpagar */
        $tipoajpagar = $this->entityManager->getRepository(Tipoajpagar::class)->findOneBy($params);

        return $tipoajpagar;
    }

    /**
     * Busca Ajuste Conta Pagar
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlanctonf
     * @param $nrseqvenpag
     * @param $nrparcelapag
     * @return Ajctpagar
     */
    public function buscaAjctpagar($nrorg, $cdfilial, $nrlanctonf, $nrseqvenpag, $nrparcelapag){
        /** @var $params */
        $params = array();
        $params['nrorg']        = $nrorg;
        $params['cdfilial']     = $cdfilial;
        $params['nrlanctonf']   = $nrlanctonf;
        $params['nrseqvenpag']  = $nrseqvenpag;
        $params['nrparcelapag'] = $nrparcelapag;

        /** @var Ajctpagar $ajctpagar */
        $ajctpagar = $this->entityManager->getRepository(Ajctpagar::class)->findOneBy($params);

        return $ajctpagar;
    }

    /**
     * Busca Ajustes Conta Pagar
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlanctonf
     * @return Ajctpagar
     */
    public function buscaAjsctpagar($nrorg, $cdfilial, $nrlanctonf, $nrseqvenpag, $nrparcelapag){
        /** @var $params */
        $params = array();
        $params['nrorg']        = $nrorg;
        $params['cdfilial']     = $cdfilial;
        $params['nrlanctonf']   = $nrlanctonf;
        $params['nrseqvenpag']  = $nrseqvenpag;
        $params['nrparcelapag'] = $nrparcelapag;

        /** @var Ajctpagar $ajctpagar */
        $ajctpagar = $this->entityManager->getRepository(Ajctpagar::class)->findBy($params);

        return $ajctpagar;
    }

    /**
     * Busca Ajuste Conta Pagar
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlanbolpag
     * @return Ajbolpag
     */
    public function buscaAjbolpag($nrorg, $cdfilial, $nrlanbolpag){
        /** @var $params */
        $params = array();
        $params['nrorg']       = $nrorg;
        $params['cdfilial']    = $cdfilial;
        $params['nrlanbolpag'] = $nrlanbolpag;

        /** @var Ajbolpag $ajbolpag */
        $ajbolpag = $this->entityManager->getRepository(Ajbolpag::class)->findOneBy($params);

        return $ajbolpag;
    }

    /**
     * Busca Ajuste Conta Pagar
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlanbolpag
     * @param $cdajuctpag
     * @return Ajbolpag
     */
    public function buscaAjbolpagCod($nrorg, $cdfilial, $nrlanbolpag, $cdajuctpag){
        /** @var $params */
        $params = array();
        $params['nrorg']       = $nrorg;
        $params['cdfilial']    = $cdfilial;
        $params['nrlanbolpag'] = $nrlanbolpag;
        $params['cdajuctpag']  = $cdajuctpag;

        /** @var Ajbolpag $ajbolpag */
        $ajbolpag = $this->entityManager->getRepository(Ajbolpag::class)->findOneBy($params);

        return $ajbolpag;
    }

    /**
     * Busca Ajuste Conta Pagar
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlanbolpag
     * @return Ajbolpag
     */
    public function buscaAjbolpags($nrorg, $cdfilial, $nrlanbolpag){
        /** @var $params */
        $params = array();
        $params['nrorg']       = $nrorg;
        $params['cdfilial']    = $cdfilial;
        $params['nrlanbolpag'] = $nrlanbolpag;

        /** @var Ajbolpag $ajbolpag */
        $ajbolpag = $this->entityManager->getRepository(Ajbolpag::class)->findBy($params);

        return $ajbolpag;
    }

    /**
     * busca Nota Fical
     * @param nrorg
     * @param cdfilirece
     * @param nrnotafisc
     * @param cdserieentr
     * @param nrinsjurnf
     * @param vrnotafisc
     * @return Notafical
     */
    public function buscaNotaFical($cdfilirece, $nrnotafisc, $cdserieentr, $nrinsjurnf, $vrnotafisc, $nrorg){
        /** @var $params */
        $params = array();
        $params['nrorg'] = $nrorg;
        $params['cdfilirece'] = $cdfilirece;
        $params['nrnotafisc'] = $nrnotafisc;
        $params['cdserieentr'] = $cdserieentr;
        $params['nrinsjurnf'] = $nrinsjurnf;
        $params['vrnotafisc'] = $vrnotafisc;
        $params['idsistema'] = 'PAG';
        $params['identrsaidop'] = 'E';

        /** @var Notafical $notaFiscal */
        $notaFiscal = $this->entityManager->getRepository(Notafiscal::class)->findOneBy($params);
        return $notaFiscal;
    }


    /**
     * busca parcela
     * @param nrorg
     * @param cdfilirece
     * @param nrnotafisc
     * @param cdserieentr
     * @param nrinsjurnf
     * @param vrnotafisc
     * @return array
     */
    public function buscaParcela($cdfilirece, $nrnotafisc, $cdserieentr, $nrinsjurnf, $vrnotafisc, $dtemissao, $nrorg){
        $params = array();
        $params['P_CDFILIRECE'] = $cdfilirece;
        $params['P_NRNOTAFISC'] = $nrnotafisc;
        $params['P_CDSERIEENTR'] = $cdserieentr;
        $params['P_NRINSJURNF'] = $nrinsjurnf;
        $params['P_VRNOTAFISC'] = $vrnotafisc;
        $params['P_DTEMISSAO'] = $dtemissao;
        $params['P_NRORG'] = $nrorg;
        $sql = "SELECT CDFILIAL, NRLANCTONF
                   FROM NOTAFISCAL
                  WHERE CDFILIRECE = :P_CDFILIRECE
                    AND NRNOTAFISC = :P_NRNOTAFISC
                    AND CDSERIEENTR = :P_CDSERIEENTR
                    AND NRINSJURNF = :P_NRINSJURNF
                    AND VRNOTAFISC = :P_VRNOTAFISC
                    AND DTEMISSAO = :P_DTEMISSAO
                    AND NRORG = :P_NRORG
                    AND IDSISTEMA = 'PAG'
                    AND IDENTRSAIDOP = 'E'";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }

    /**
     * Busca Lançamento Contabil
     * @param $nrorg
     * @param $cdempresa
     * @param $nrlanccont
     * @return Lanccont
     */
    public function buscaLanccont($nrorg, $cdempresa, $nrlanccont){
        /** @var $params */
        $params = array();
        $params['nrorg']      = $nrorg;
        $params['cdempresa']  = $cdempresa;
        $params['nrlanccont'] = $nrlanccont;

        /** @var Lanccont $lanccont */
        $lanccont = $this->entityManager->getRepository(Lanccont::class)->findBy($params);

        return $lanccont;
    }

    /**
     * Insere Nota Fiscal Pagar
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlanctonf
     * @param $cdempresa
     * @param $cdinscesta
     * @param $cdinscmuni
     * @param $cdfilirece
     * @param $idtpijurnf
     * @param $nrinsjurnf
     * @param $cdforneced
     * @param $idbloqueado
     * @param $iddocfiscal
     * @param $iddocfinanc
     * @param $vrprodutos
     * @param $dtliberacaofin
     * @param $vrnotafisc
     * @param $nrnotafisc
     * @param $dtemissao
     * @param $dtentrsaid
     * @param $identrsaidop
     * @param $cdtipooper
     * @param $cdserieentr
     * @param $iddoccontab
     * @param $idstatus
     * @param $idsistema
     * @param $dtlancamennf
     * @param $cdoperactpg
     * @return Notafiscal
     */
    public function insereNotaFiscalPagar(
        $nrorg, $cdfilial, $nrlanctonf, $cdempresa, $cdinscesta, $cdinscmuni, $cdfilirece,
        $idtpijurnf, $nrinsjurnf, $cdforneced, $idbloqueado, $iddocfiscal, $iddocfinanc,
        $vrprodutos, $dtliberacaofin, $vrnotafisc, $nrnotafisc, $dtemissao, $dtentrsaid, $identrsaidop,
        $cdtipooper, $cdserieentr, $iddoccontab, $idstatus, $idsistema, $dtlancamennf, $cdoperactpg
    ){

        /** @var Notafiscal $notafiscal */
        $notafiscal = new Notafiscal();
        $notafiscal->setNrorg($nrorg);
        $notafiscal->setCdfilial($cdfilial);
        $notafiscal->setNrlanctonf($nrlanctonf);
        $notafiscal->setCdempresa($cdempresa);
        $notafiscal->setCdinscesta($cdinscesta);
        $notafiscal->setCdinscmuni($cdinscmuni);
        $notafiscal->setCdfilirece($cdfilirece);
        $notafiscal->setIdtpijurnf($idtpijurnf);
        $notafiscal->setNrinsjurnf($nrinsjurnf);
        $notafiscal->setCdforneced($cdforneced);
        $notafiscal->setIdbloqueado($idbloqueado);
        $notafiscal->setIddocfiscal($iddocfiscal);
        $notafiscal->setIddocfinanc($iddocfinanc);
        $notafiscal->setVrprodutos($vrprodutos);
        $notafiscal->setDtliberacaofin($dtliberacaofin);
        $notafiscal->setVrnotafisc($vrnotafisc);
        $notafiscal->setNrnotafisc($nrnotafisc);
        $notafiscal->setDtemissao($dtemissao);
        $notafiscal->setDtentrsaid($dtentrsaid);
        $notafiscal->setIdentrsaidop($identrsaidop);
        $notafiscal->setCdtipooper($cdtipooper);
        $notafiscal->setCdserieentr($cdserieentr);
        $notafiscal->setIddoccontab($iddoccontab);
        $notafiscal->setIdstatus($idstatus);
        $notafiscal->setIdsistema($idsistema);
        $notafiscal->setDtlancamennf($dtlancamennf);
        $notafiscal->setCdoperactpg($cdoperactpg);
        $notafiscal->setDtinclusao(DateUtil::getDataAtual());

        return $notafiscal;
    }

    /**
     * Insere Boleto Pagar
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlanbolpag
     * @param $cdforneced
     * @param $cdempresa
     * @param $vrbolpag
     * @param $vrfinalbpag
     * @param $dtvenbolpag
     * @param $vrpemulbpag
     * @param $vrmultabpag
     * @param $vrpemorbpag
     * @param $vrmordiabpag
     * @param $cdbancbolp
     * @param $cdagenbolp
     * @param $cdccorbolp
     * @return Boletpagar
     */
    public function insereBoletoPagar(
        $nrorg, $cdfilial, $nrlanbolpag, $cdforneced, $cdempresa, $vrbolpag, $vrfinalbpag,
        $dtvenbolpag, $vrpemulbpag, $vrmultabpag , $vrpemorbpag , $vrmordiabpag,
        $cdbancbolp, $cdagenbolp, $cdccorbolp, $idhabibpag, $cdoperinclusao, $cdfililanc, $cdtpbaixapag = null
    ){
        /** @var Boletpagar $boletpagar */
        $boletpagar = new Boletpagar();
        $boletpagar->setNrorg($nrorg);
        $boletpagar->setCdfilial($cdfilial);
        $boletpagar->setNrlanbolpag($nrlanbolpag);
        $boletpagar->setCdforneced($cdforneced);
        $boletpagar->setCdempresa($cdempresa);
        $boletpagar->setVrbolpag($vrbolpag);
        $boletpagar->setVrfinalbpag($vrfinalbpag);
        $boletpagar->setDtvenbolpag($dtvenbolpag);
        $boletpagar->setVrpemulbpag($vrpemulbpag);
        $boletpagar->setVrmultabpag($vrmultabpag);
        $boletpagar->setVrpemorbpag($vrpemorbpag);
        $boletpagar->setVrmordiabpag($vrmordiabpag);
        $boletpagar->setCdbancbolp($cdbancbolp);
        $boletpagar->setCdagenbolp($cdagenbolp);
        $boletpagar->setCdccorbolp($cdccorbolp);
        $boletpagar->setIdhabibpag($idhabibpag);
        $boletpagar->setCdoperinclusao($cdoperinclusao);
        $boletpagar->setCdfililanc($cdfililanc);
        $boletpagar->setCdtpbaixapag($cdtpbaixapag);
        
        $boletpagar->setDtinclusao(DateUtil::getDataAtual());

        return $boletpagar;
    }

    /**
     * Insere Conta a Pagar
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlanctonf
     * @param $nrseqvenpag
     * @param $nrparcelapag
     * @param $dtorigvenpag
     * @param $vratuapag
     * @param $cdtpctpagar
     * @param $dtatuavenpag
     * @param $vrorigpag
     * @param $cdfilibpag
     * @param $nrlanbolpag
     * @param $idstatpag
     * @param $qtdiasvenpag
     * @param $cdclassfina
     * @param $cdempresa
     * @param $dtmovfluxo
     * @param $idmovfluxo
     * @param $cdfimovflpag
     * @param $dscontapag
     * @return Contapagar
     */
    public function insereContaPagar(
        $nrorg, $cdfilial, $nrlanctonf, $nrseqvenpag, $nrparcelapag, $dtorigvenpag,
        $vratuapag, $cdtpctpagar, $dtatuavenpag, $vrorigpag, $cdfilibpag, $nrlanbolpag,
        $idstatpag, $qtdiasvenpag, $cdclassfina, $cdempresa, $dtmovfluxo,
        $idmovfluxo, $cdfimovflpag, $dscontapag
    ){
        /** @var Contapagar $contapagar */
        $contapagar = new Contapagar();
        $contapagar->setNrorg($nrorg);
        $contapagar->setCdfilial($cdfilial);
        $contapagar->setNrlanctonf($nrlanctonf);
        $contapagar->setNrseqvenpag($nrseqvenpag);
        $contapagar->setNrparcelapag($nrparcelapag);
        $contapagar->setDtorigvenpag($dtorigvenpag);
        $contapagar->setVratuapag($vratuapag);
        $contapagar->setCdtpctpagar($cdtpctpagar);
        $contapagar->setDtatuavenpag($dtatuavenpag);
        $contapagar->setVrorigpag($vrorigpag);
        $contapagar->setCdfilibpag($cdfilibpag);
        $contapagar->setNrlanbolpag($nrlanbolpag);
        $contapagar->setIdstatpag($idstatpag);
        $contapagar->setQtdiasvenpag($qtdiasvenpag);
        $contapagar->setDscontapag($dscontapag);
        $contapagar->setCdclassfina($cdclassfina);
        $contapagar->setCdempresa($cdempresa);
        $contapagar->setDtmovfluxo($dtmovfluxo);
        $contapagar->setIdmovfluxo($idmovfluxo);
        $contapagar->setCdfimovflpag($cdfimovflpag);
        $contapagar->setDtinclusao(DateUtil::getDataAtual());

        return $contapagar;
    }

    /**
     * Insere Rateio Conta Pagar
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlanctonf
     * @param $nrseqvenpag
     * @param $nrparcelapag
     * @param $cdfiratctpag
     * @param $cdcentcust
     * @param $vrratccctpag
     * @return Ratctpagar
     */
    public static function insereRatCtPagar(
        $nrorg, $cdfilial, $nrlanctonf, $nrseqvenpag, $nrparcelapag, $cdcentcust, $cdfiratctpag, $vrratccctpag
    ){
        /** @var Ratctpagar $rateiopagar */
        $rateiopagar = new Ratctpagar();
        $rateiopagar->setNrorg($nrorg);
        $rateiopagar->setCdfilial($cdfilial);
        $rateiopagar->setNrlanctonf($nrlanctonf);
        $rateiopagar->setNrseqvenpag($nrseqvenpag);
        $rateiopagar->setNrparcelapag($nrparcelapag);
        $rateiopagar->setCdfiratctpag($cdfiratctpag);
        $rateiopagar->setCdcentcust($cdcentcust);
        $rateiopagar->setVrratccctpag($vrratccctpag);
        $rateiopagar->setDtinclusao(DateUtil::getDataAtual());

        return $rateiopagar;
    }

    /**
     * Insere Rateio Tipo Conta Pagar
     * @param $nrorg
     * @param $cdfilial
     * @param $cdfilirece
     * @param $cdcentcust
     * @param $vrperattpctp
     * @return Rattpctp
     */
    public static function insereRatTpCtP(
        $nrorg, $cdfilial, $cdfilirece, $cdcentcust, $vrperattpctp
    ){
        /** @var Rattpctp $rattpctp */
        $rattpctr = New Rattpctp();
        $rattpctr->setNrorg($nrorg);
        $rattpctr->setCdfilial($cdfilial);
        $rattpctr->setCdfirattpctp($cdfilirece);
        $rattpctr->setCdcentcust($cdcentcust);
        $rattpctr->setVrperattpctp($vrperattpctp);
        $rattpctr->setDtinclusao(DateUtil::getDataAtual());

        return $rattpctr;
    }

    /**
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlanbolpag
     * @param $cdajuctpag
     * @param $vrajbolpag
     * @return Ajbolpag
     */
    public static function insereAjBolPag(
        $nrorg, $cdfilial, $nrlanbolpag, $cdajuctpag, $vrajbolpag
    ){
        $ajbolpag = new Ajbolpag();
        $ajbolpag->setNrorg($nrorg);
        $ajbolpag->setCdfilial($cdfilial);
        $ajbolpag->setNrlanbolpag($nrlanbolpag);
        $ajbolpag->setCdajuctpag($cdajuctpag);
        $ajbolpag->setVrajbolpag($vrajbolpag);
        $ajbolpag->setDtinclusao(DateUtil::getDataAtual());

        return $ajbolpag;
    }

    /**
     * Insere Adiantamento Pagar
     * @param $nradiantapagar
     * @param $cdfilial
     * @param $nrlanctonf
     * @param $nrlanbolpag
     * @param $nrseqvenpag
     * @param $nrparcelapag
     * @param $vrdesconto
     * @param $nrorg
     * @param $cdajuctpag
     * @param $dtadiantapag
     * @param $cdoperador
     * @return Adiantapagar
     */
    public static function insereAdiantaPagar(
        $nradiantapagar, $cdfilial, $cdfiliajbolp, $nrlanctonf, $nrlanbolpag,
        $nrseqvenpag, $nrparcelapag, $vrdesconto, $nrorg, $cdajuctpag, $dtadiantapag,
        $cdoperador
    ){
        $adiantapagar = new Adiantapagar();
        $adiantapagar->setNrorg($nrorg);
        $adiantapagar->setNradiantapagar($nradiantapagar);
        $adiantapagar->setCdfilial($cdfilial);
        $adiantapagar->setCdfiliajbolp($cdfiliajbolp);
        $adiantapagar->setNrlanctonf($nrlanctonf);
        $adiantapagar->setNrlanbolpag($nrlanbolpag);
        $adiantapagar->setNrseqvenpag($nrseqvenpag);
        $adiantapagar->setNrparcelapag($nrparcelapag);
        $adiantapagar->setVradiantapag($vrdesconto);
        $adiantapagar->setCdajuctpag($cdajuctpag);
        $adiantapagar->setDtadiantapag($dtadiantapag);
        $adiantapagar->setDtinclusao(DateUtil::getDataAtual());
        $adiantapagar->setCdoperinclusao($cdoperador);

        return $adiantapagar;
    }

    /**
     * Insere Devolução Pagar
     * @param $nrorg
     * @param $cdfilial
     * @param $cdfilibolpag
     * @param $nrlanbolpag
     * @param $nrdevolucaopag
     * @param $dtdevolucaopag
     * @param $nrlanctonf
     * @param $cdajuctpag
     * @param $vrdevolucaopag
     * @param $cdoperador
     * @return Devolucaopag
     */
    public static function insereDevolucaoPag(
        $nrorg, $cdfilial, $cdfilibolpag, $nrlanbolpag, $nrdevolucaopag,
        $dtdevolucaopag, $nrlanctonf, $cdajuctpag, $vrdevolucaopag, $cdoperador
    ){
        /** @var Devolucaopag $devolucaopag */
        $devolucaopag = New Devolucaopag();
        $devolucaopag->setNrorg($nrorg);
        $devolucaopag->setCdfilial($cdfilial);
        $devolucaopag->setCdfilibolpag($cdfilibolpag);
        $devolucaopag->setNrlanbolpag($nrlanbolpag);
        $devolucaopag->setNrdevolucaopag($nrdevolucaopag);
        $devolucaopag->setDtdevolucaopag($dtdevolucaopag);
        $devolucaopag->setNrlanctonf($nrlanctonf);
        $devolucaopag->setCdajuctpag($cdajuctpag);
        $devolucaopag->setVrdevolucaopag($vrdevolucaopag);
        $devolucaopag->setDtinclusao(DateUtil::getDataAtual());
        $devolucaopag->setCdoperinclusao($cdoperador);

        return $devolucaopag;
    }

    /**
     * Insere Antecipação de Fornecedor
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlancantecipa
     * @param $cdforneced
     * @param $cdfiliorig
     * @param $cdmotipror
     * @param $cdreducontpag
     * @param $cdtpbaixapag
     * @param $idstatusantecip
     * @param $dtlancantecipa
     * @param $dtvencantecipa
     * @param $vrcontaantecipa
     * @param $vrliquantecipa
     * @param $vrpemulantecipa
     * @param $vrpemoraantecip
     * @param $vrmultaantecipa
     * @param $vrmoraantecipa
     * @param $dslinhbaranteci
     * @param $cdbarraantecipa
     * @param $dsantecipaforn
     * @param $cdempresa
     * @param $dtemisantecipa
     * @param $cdbancantecipa
     * @param $cdagenantecipa
     * @param $cdccorantecipa
     * @param $cdempresa
     * @return Antecipaforne
     */
    public static function insereAntecipaforne(
        $nrorg, $cdfilial, $nrlancantecipa, $cdforneced, $cdfiliorig, $cdmotipror, $cdreducontpag,
        $cdtpbaixapag, $idstatusantecip, $dtlancantecipa, $dtvencantecipa, $vrcontaantecipa, $vrliquantecipa,
        $vrpemulantecipa, $vrpemoraantecip,
        $vrmultaantecipa, $vrmoraantecipa, $dslinhbaranteci, $cdbarraantecipa, $dsantecipaforn, $cdempresa,
        $dtemisantecipa, $cdbancantecipa, $cdagenantecipa, $cdccorantecipa, $cdempresa1
    ){
        /** @var Antecipaforne $antecipaforne */
        $antecipaforne = New Antecipaforne();
        $antecipaforne->setNrorg($nrorg);
        $antecipaforne->setCdfilial($cdfilial);
        $antecipaforne->setNrlancantecipa($nrlancantecipa);
        $antecipaforne->setCdforneced($cdforneced);
        $antecipaforne->setCdfiliorig($cdfiliorig);
        $antecipaforne->setCdmotipror($cdmotipror);
        $antecipaforne->setCdreducontpag($cdreducontpag);
        $antecipaforne->setCdtpbaixapag($cdtpbaixapag);
        $antecipaforne->setIdstatusantecip($idstatusantecip);
        $antecipaforne->setDtlancantecipa($dtlancantecipa);
        $antecipaforne->setDtvencantecipa($dtvencantecipa);
        $antecipaforne->setVrcontaantecipa($vrcontaantecipa);
        $antecipaforne->setVrliquantecipa($vrliquantecipa);
        $antecipaforne->setVrpemulantecipa($vrpemulantecipa);
        $antecipaforne->setVrpemoraantecip($vrpemoraantecip);
        $antecipaforne->setVrmultaantecipa($vrmultaantecipa);
        $antecipaforne->setVrmoraantecipa($vrmoraantecipa);
        $antecipaforne->setDslinhbaranteci($dslinhbaranteci);
        $antecipaforne->setCdbarraantecipa($cdbarraantecipa);
        $antecipaforne->setDsantecipaforn($dsantecipaforn);
        $antecipaforne->setCdempresa($cdempresa);
        $antecipaforne->setDtemisantecipa($dtemisantecipa);
        $antecipaforne->setCdbancantecipa($cdbancantecipa);
        $antecipaforne->setCdagenantecipa($cdagenantecipa);
        $antecipaforne->setCdccorantecipa($cdccorantecipa);
        $antecipaforne->setCdempresa($cdempresa);
        $antecipaforne->setDtinclusao(DateUtil::getDataAtual());

        return $antecipaforne;
    }

    /**
     * Atualiza Rateio Conta Pagar
     * @param Ratctpagar $ratctpagar
     * @param $vrratccctpag
     * @return Ratctpagar
     */
    public static function atualizaRatCtPagar(
        Ratctpagar $ratctpagar, $vrratccctpag
    ){
        $ratctpagar->setVrratccctpag($vrratccctpag);

        return $ratctpagar;
    }

    /**
     * Atualiza Nota Fiscal
     * @param Notafiscal $notafiscal
     * @param $nrnotafisc
     * @param $dtemissao
     * @param $dtentrsaid
     * @param $cdserie
     * @param $idstatus
     * @param $nrlanccont
     * @param $vrprodutos
     * @param $vrnotafisc
     * @return mixed
     */
    public static function atualizaNotaFiscal(
        Notafiscal $notafiscal, $nrnotafisc, $dtemissao, $dtentrsaid, $cdserie, $idstatus, $nrlanccont,
        $vrprodutos, $vrnotafisc
    ){
        $notafiscal->setNrnotafisc($nrnotafisc);
        $notafiscal->setDtemissao($dtemissao);
        $notafiscal->setDtentrsaid($dtentrsaid);
        $notafiscal->setCdserieentr($cdserie);
        $notafiscal->setIdstatus($idstatus);
        $notafiscal->setNrlanccont($nrlanccont);
        $notafiscal->setVrprodutos($vrprodutos);
        $notafiscal->setVrnotafisc($vrnotafisc);

        return $notafiscal;
    }

    /**
     * Atualiza Boleto Antecipado
     * @param Boletpagar $boletpagar
     * @param $nrlancantecipa
     * @param $cdtpbaixapag
     * @param $cdreducontpag
     * @param $dslinhbaranteci
     * @param $cdbarraantecipa
     * @param $cdbancantecipa
     * @param $cdagenantecipa
     * @param $cdccorantecipa
     * @param $vrpemulantecipa
     * @param $vrpemoraantecip
     * @param $vrmultaantecipa
     * @param $vrmoraantecipa
     * @param $cdfililanc
     * @param $idbpagreal
     * @param $idhabibpag
     * @return mixed
     */
    public static function atualizaBoletoAntecipado(
        Boletpagar $boletpagar, $nrlancantecipa, $cdtpbaixapag, $cdreducontpag, $dslinhbaranteci,
        $cdbarraantecipa, $cdbancantecipa, $cdagenantecipa, $cdccorantecipa, $vrpemulantecipa,
        $vrpemoraantecip, $vrmultaantecipa, $vrmoraantecipa, $cdfililanc, $idbpagreal, $idhabibpag
    ){
        $boletpagar->setNrlancantecipa($nrlancantecipa);
        $boletpagar->setCdtpbaixapag($cdtpbaixapag);
        $boletpagar->setCdreducont($cdreducontpag);
        $boletpagar->setDslinhbarpag($dslinhbaranteci);
        $boletpagar->setCdbarrapag($cdbarraantecipa);
        $boletpagar->setCdbancbolp($cdbancantecipa);
        $boletpagar->setCdagenbolp($cdagenantecipa);
        $boletpagar->setCdccorbolp($cdccorantecipa);
        $boletpagar->setVrpemulbpag($vrpemulantecipa);
        $boletpagar->setVrpemorbpag($vrpemoraantecip);
        $boletpagar->setVrmultabpag($vrmultaantecipa);
        $boletpagar->setVrmordiabpag($vrmoraantecipa);
        $boletpagar->setCdfililanc($cdfililanc);
        $boletpagar->setIdbpagreal($idbpagreal);
        $boletpagar->setIdhabibpag($idhabibpag);

        return $boletpagar;
    }

    /**
     * Atualiza Nota Fiscal
     * @param Notafiscal $notafiscal
     * @param $vrdevolnfutl
     * @return Notafiscal
     */
    public static function atualizaNotaFiscalDev(
        Notafiscal $notafiscal, $vrdevolnfutl
    ){
        $notafiscal->setVrdevolnfutl($vrdevolnfutl);

        return $notafiscal;
    }

    /**
     * Atualiza Conta Pagar
     * @param Contapagar $contapagar
     * @param $cdtpctpagar
     * @param $dtatuavenpag
     * @param $cdclassfina
     * @param $dtmovfluxo
     * @param $idmovfluxo
     * @return mixed
     */
    public static function atualizaContaPagar(
        Contapagar $contapagar, $cdtpctpagar, $dtatuavenpag, $cdclassfina, $dtmovfluxo, $idmovfluxo,
        $vrorigpag, $vratuapag, $dscontapag
    ){
        $contapagar->setCdtpctpagar($cdtpctpagar);
        $contapagar->setDtatuavenpag($dtatuavenpag);
        $contapagar->setCdclassfina($cdclassfina);
        $contapagar->setDtmovfluxo($dtmovfluxo);
        $contapagar->setIdmovfluxo($idmovfluxo);
        $contapagar->setVrorigpag($vrorigpag);
        $contapagar->setVratuapag($vratuapag);
        $contapagar->setDscontapag($dscontapag);

        return $contapagar;
    }

    /**
     * Atualiza Boleto Pagar
     * @param $boletpagar
     * @param $cdreducont
     * @param $cdtpbaixapag
     * @param $cdbancbolp
     * @param $cdagenbolp
     * @param $cdccorbolp
     * @param $vrpemulbpag
     * @param $vrpemorbpag
     * @param $vrmultabpag
     * @param $vrmordiabpag
     * @return mixed
     */
    public function atualizaBoletPagar(
        Boletpagar $boletpagar, $cdreducont, $cdtpbaixapag, $cdbancbolp, $cdagenbolp, $cdccorbolp,
        $vrpemulbpag, $vrpemorbpag, $vrmultabpag, $vrmordiabpag, $dslinhbarpag, $cdbarrapag,
        $chavepix, $codeqrpix, $idchavepix, $dschavepix
    ){
        $boletpagar->setCdreducont($cdreducont);
        $boletpagar->setCdtpbaixapag($cdtpbaixapag);
        $boletpagar->setCdbancbolp($cdbancbolp);
        $boletpagar->setCdagenbolp($cdagenbolp);
        $boletpagar->setCdccorbolp($cdccorbolp);
        $boletpagar->setVrpemulbpag($vrpemulbpag);
        $boletpagar->setVrpemorbpag($vrpemorbpag);
        $boletpagar->setVrmultabpag($vrmultabpag);
        $boletpagar->setVrmordiabpag($vrmordiabpag);
        $boletpagar->setDslinhbarpag($dslinhbarpag);
        $boletpagar->setCdbarrapag($cdbarrapag);
        $boletpagar->setChavepix($chavepix);
        $boletpagar->setCodeqrpix($codeqrpix);
        $boletpagar->setIdchavepix($idchavepix);
        $boletpagar->setDschavepix($dschavepix);

        return $boletpagar;
    }

    /**
     * Atualiza Valor Boleto Pagar
     * @param $boletpagar
     * @param $vrbolpag
     * @param $vrfinalbpag
     * @return mixed
     */
    public function atualizaValorBoletPagar(
        Boletpagar $boletpagar, $vrbolpag, $vrfinalbpag
    ){
        $boletpagar->setVrbolpag($vrbolpag);
        $boletpagar->setVrfinalbpag($vrfinalbpag);

        return $boletpagar;
    }

    /**
     * Atualiza Valor Boleto Pagar
     * @param $boletpagar
     * @param $vrbolpag
     * @param $vrfinalbpag
     * @return mixed
     */
    public function atualizaBoletPagarGuiaTributo(
        Boletpagar $boletpagar, $cdreceitaguia, $dtapuracguia, $nrrefeguia, $vroutrentguia, $vrpercenttrib
    ){
        $boletpagar->setCdreceitaguia($cdreceitaguia);
        $boletpagar->setDtapuracguia($dtapuracguia);
        $boletpagar->setNrrefeguia($nrrefeguia);
        $boletpagar->setVroutrentguia($vroutrentguia);
        $boletpagar->setVrpercenttrib($vrpercenttrib);

        return $boletpagar;
    }

    /**
     * Get Sequencial Nota Fiscal
     * @param $cdfilial
     * @param $nrlanctonf
     * @param $nrorg
     * @return count
     */
    public function getSequencialNotaFiscal($cdfilial, $nrlanctonf, $nrorg){
        $params = array();
        $params['P_CDFILIAL'] = $cdfilial;
        $params['P_NRLANCTONF'] = $nrlanctonf;
        $params['P_NRORG'] = $nrorg;
        $sql = "SELECT COUNT(*) as QUANT  FROM CONTAPAGAR WHERE CDFILIAL = :P_CDFILIAL AND NRLANCTONF = :P_NRLANCTONF AND NRORG = :P_NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    /**
     * Valida Filial Logada Po Empresa Filtrada
     * @param $cdempresa
     * @param $cdfilial
     */
    public function validaFilialLogadaPorEmpresaFiltrada($cdempresa, $cdfilial){
        $params = array();
        $params['CDFILIAL']  = $cdfilial;
        $params['CDEMPRESA'] = $cdempresa;
        $sql = "SELECT FI.NRORG     ,
                       FI.CDFILIAL  ,
                       FI.NMFILIAL  ,
                       FI.CDEMPRESA ,
                       FI.CDINSCESTA,
                       FI.CDINSCMUNI,
                       NVL(PF.NRTAMNUMNFUTDFE,0) AS NRTAMNUMNFUTDFE
                  FROM PARAMFILIAL PF,
                       FILIAL      FI
                 WHERE (FI.CDFILIAL   = :CDFILIAL  )
                   AND (FI.CDEMPRESA  = :CDEMPRESA )
                   AND (PF.CDFILIAL   = FI.CDFILIAL)
                   AND (FI.IDCNTRRESC = 'N'        )
                 UNION
                SELECT FI.NRORG     ,
                       EF.CDFILIAL  ,
                       FI.NMFILIAL  ,
                       EF.CDEMPRESA ,
                       EF.CDINSCESTA,
                       EF.CDINSCMUNI,
                       NVL(PF.NRTAMNUMNFUTDFE,0) AS NRTAMNUMNFUTDFE
                  FROM PARAMFILIAL PF,
                       FILIAL      FI,
                       EMPRCNTRFIL EF
                 WHERE (FI.CDFILIAL   = :CDFILIAL  )
                   AND (EF.CDEMPRESA  = :CDEMPRESA )
                   AND (FI.CDFILIAL   = EF.CDFILIAL)
                   AND (PF.CDFILIAL   = FI.CDFILIAL)
                   AND (FI.IDCNTRRESC = 'N'        )
                 ORDER BY CDFILIAL";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    /**
     * Atualiza Boleto Pagar
     * @param Boletpagar $ratctpagar
     * @param $idhabibpag
     * @return Boletpagar
     */
    public static function atualizaBoletPagarHabilitado(
        Boletpagar $boletpagar, $idhabibpag
    ){
        $boletpagar->setIdhabibpag($idhabibpag);

        return $boletpagar;
    }
    
    /**
     * Busca GeralPag
     * @param $nrorg
     * @return GeralPag
     */
    public function buscaGeralPag($nrorg){
        /** @var $params */
        $params = array();
        $params['nrorg'] = $nrorg;

        /** @var GeralPag $geralpag */
        $geralpag = $this->entityManager->getRepository(GeralPag::class)->findOneBy($params);

        return $geralpag;
    }
    
    /**
     * Executa Procedure GRAVA_BAIXA_IMPOSTO
     * @param $cdfilial
     * @param $nrbaixa
     * @param $cdreducont
     * @param $nrmovidebi
     * @param $idoperacao
     */
    public function execGravaBaixaImposto(
        $cdfilial, $nrbaixa, $cdreducont, $nrmovidebi, $idoperacao
    ){
        $procedure = new StoredProcedure($this->entityManager->getConnection(), 'GRAVA_BAIXA_IMPOSTO');
        $procedure->addParam(new Param('P_CDFILIAL'  , Param::PARAM_INPUT, $cdfilial   , Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRBAIXA'   , Param::PARAM_INPUT, $nrbaixa    , Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDREDUCONT', Param::PARAM_INPUT, $cdreducont , Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRMOVIDEBI', Param::PARAM_INPUT, $nrmovidebi , Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDOPERACAO', Param::PARAM_INPUT, $idoperacao , Param::PARAM_TYPE_STR));

        $procedure->execute();
    }
    
    public function salvaAnexoTitulo($row){
        $params = array(
            'NRANEXOLANCBOL' => $row['NRANEXOLANCBOL'],
            'CDTELA'         => $row['CDTELA'],
            'DTANEXOLANCBOL' => $row['DTANEXOLANCBOL'],
            'NMANEXOLANCBOL' => $row['NMANEXOLANCBOL'][0]["name"],
            'NMPATHANEXO'    => $row['NMPATHANEXO'],
            'DSANEXOLANCBOL' => isset($row['DSANEXOLANCBOL']) ? $row['DSANEXOLANCBOL'] : null,
            'DSINFOANEXO'    => $row['DSINFOANEXO'],
            'NRORG'          => $row['NRORG']
        );
        
        $sql = "INSERT INTO ANEXOLANCBOL 
            (
                NRANEXOLANCBOL,
                CDTELA,
                DTANEXOLANCBOL,
                NMANEXOLANCBOL,
                NMPATHANEXO,
                DSANEXOLANCBOL,
                DSINFOANEXO,
                NRORG
            ) VALUES (
                :NRANEXOLANCBOL,
                :CDTELA,
                :DTANEXOLANCBOL,
                :NMANEXOLANCBOL,
                :NMPATHANEXO,
                :DSANEXOLANCBOL,
                :DSINFOANEXO,
                :NRORG
            )";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);

    }
    
    public function salvaAnexoGrid($row){
        $params = array(
            'NRANEXOLANCBOL' => $row['NRANEXOLANCBOL'],
            'NRLANBOLPAG'    => $row['NRLANBOLPAG'],
            'CDFILIAL'       => $row['CDFILIAL'],
            'CDTELA'         => $row['CDTELA'],
            'DTANEXOLANCBOL' => $row['DTANEXOLANCBOL'],
            'NMANEXOLANCBOL' => $row['NMANEXOLANCBOL'][0]["name"],
            'NMPATHANEXO'    => $row['NMPATHANEXO'],
            'DSANEXOLANCBOL' => isset($row['DSANEXOLANCBOL']) ? $row['DSANEXOLANCBOL'] : null,
            'DSINFOANEXO'    => $row['DSINFOANEXO'],
            'NRORG'          => $row['NRORG']
        );
        
        $sql = "INSERT INTO ANEXOLANCBOL 
            (
                NRANEXOLANCBOL,
                NRLANBOLPAG,
                CDFILIAL,
                CDTELA,
                DTANEXOLANCBOL,
                NMANEXOLANCBOL,
                NMPATHANEXO,
                DSANEXOLANCBOL,
                DSINFOANEXO,
                NRORG
            ) VALUES (
                :NRANEXOLANCBOL,
                :NRLANBOLPAG,
                :CDFILIAL,
                :CDTELA,
                :DTANEXOLANCBOL,
                :NMANEXOLANCBOL,
                :NMPATHANEXO,
                :DSANEXOLANCBOL,
                :DSINFOANEXO,
                :NRORG
            )";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);

    }
    
    public function deletaAnexoTitulo($row){
        $params = array(
            'NRANEXOLANCBOL' => $row['NRANEXOLANCBOL'],
            'CDTELA'         => $row['CDTELA']
        );
        
        $sql = "DELETE FROM ANEXOLANCBOL 
            WHERE    
                NRANEXOLANCBOL = :NRANEXOLANCBOL
                AND CDTELA = :CDTELA";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);

    }

    public function selectDeleteAnexoIncompletos(){
        $params = array(
            'CDTELA' => 'PAG00001'
        );
        
        $sql = "SELECT * FROM ANEXOLANCBOL 
            WHERE CDTELA = :CDTELA
            AND NRLANBOLPAG IS NULL
            AND NRLANBOLREC IS NULL
            AND CDFILIAL IS NULL";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();

    }
    
    public function deleteAnexoIncompletos($row){
        $params = array(
            'CDTELA'         => 'PAG00001'
        );
        
        $sql = "DELETE FROM ANEXOLANCBOL 
            WHERE CDTELA = :CDTELA
            AND NRLANBOLPAG IS NULL
            AND NRLANBOLREC IS NULL
            AND CDFILIAL IS NULL";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);

    }
    
    public function uptadeAnexos($row){
        $params = array(
            'CDTELA'         => 'PAG00001',
            'NRLANBOLPAG'    => $row['NRLANBOLPAG'],
            'CDFILIAL'       => $row['CDFILIAL'],
            'NMPATHANEXO'    => $row['NMPATHANEXO'],
            'NRANEXOLANCBOL' => $row['NRANEXOLANCBOL']
        );
        
        $sql = "UPDATE ANEXOLANCBOL 
            SET NRLANBOLPAG = :NRLANBOLPAG,
            CDFILIAL = :CDFILIAL,
            NMPATHANEXO = :NMPATHANEXO
            WHERE CDTELA = :CDTELA
            AND NRANEXOLANCBOL = :NRANEXOLANCBOL";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);

    }
    
    public function buscaTipoBaixaPagPrefBolPag($cdforneced, $cdfilirece, $cdempresa){
        
        $params = array();
        
        $params['CDFORNECED'] = $cdforneced;
        $params['CDFILIRECE'] = $cdfilirece;
        $params['CDEMPRESA']  = $cdempresa;
        
        $sql = "SELECT TB.IDBAIXAUTILP, T.CDTPBAIXAPAG FROM (
                                SELECT NVL(CDTPBAIXAPAG, 
                                                         (SELECT NVL(CDTPBAIXAPAG, 
                                                                                   (SELECT CDTPBAIXAPAG 
                                                                                      FROM PARAMEMPRESA 
                                                                                     WHERE CDEMPRESA = :CDEMPRESA))
                                                            FROM PARAMFILIAL 
                                                           WHERE CDFILIAL = :CDFILIRECE)) CDTPBAIXAPAG
                                  FROM FORNECEDOR
                                 WHERE CDFORNECED = :CDFORNECED
                ) T, TIPOBAIXAPAG TB
                WHERE T.CDTPBAIXAPAG = TB.CDTPBAIXAPAG";
                    
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        
        return $std->fetch();
    }
    
    public function verificaDadosGuiaTributo($params){
        
        $sql = "SELECT CDRECEITAGUIA, DTAPURACGUIA, VROUTRENTGUIA,VRPERCENTTRIB, NRREFEGUIA
                FROM BOLETPAGAR
                WHERE NRLANBOLPAG = :NRLANBOLPAG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();

    }
    
}